@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'stringio'
 require 'ostruct'
 
@@ -6,7 +7,7 @@ module YARD
     # Raised when an object is recognized but cannot be documented. This
     # generally occurs when the Ruby syntax used to declare an object is
     # too dynamic in nature.
-    class UndocumentableError < Exception; end
+    class UndocumentableError < RuntimeError; end
 
     # Raised when the parser sees a Ruby syntax error
     class ParserSyntaxError < UndocumentableError; end
@@ -39,7 +40,8 @@ module YARD
       #
       # @see Processor#parse_remaining_files
       def parse
-        while file = files.shift
+        until files.empty?
+          file = files.shift
           log.capture("Parsing #{file}") do
             SourceParser.new(SourceParser.parser_type, @global_state).parse(file)
           end
@@ -61,17 +63,22 @@ module YARD
     # @see CodeObjects::Base
     class SourceParser
       SHEBANG_LINE  = /\A\s*#!\S+/
-      ENCODING_LINE = /\A(?:\s*#*!.*\r?\n)?\s*(?:#+|\/\*+|\/\/+).*coding\s*[:=]{1,2}\s*([a-z\d_\-]+)/i
+      ENCODING_LINE = %r{\A(?:\s*#*!.*\r?\n)?\s*(?:#+|/\*+|//+).*coding\s*[:=]{1,2}\s*([a-z\d_\-]+)}i
+      FROZEN_STRING_LINE = /frozen(-|_)string(-|_)literal:\s+(true|false)/i
+
+      # The default glob of files to be parsed.
+      # @since 0.9.0
+      DEFAULT_PATH_GLOB = ["{lib,app}/**/*.rb", "ext/**/*.{c,cc,cxx,cpp,rb}"]
 
       # Byte order marks for various encodings
       # @since 0.7.0
       ENCODING_BYTE_ORDER_MARKS = {
-        'utf-8' => "\xEF\xBB\xBF",
+        'utf-8' => String.new("\xEF\xBB\xBF"),
         # Not yet supported
-        #'utf-16be' => "\xFE\xFF",
-        #'utf-16le' => "\xFF\xFE",
-        #'utf-32be' => "\x00\x00\xFF\xFE",
-        #'utf-32le' => "\xFF\xFE",
+        # 'utf-16be' => "\xFE\xFF",
+        # 'utf-16le' => "\xFF\xFE",
+        # 'utf-32be' => "\x00\x00\xFF\xFE",
+        # 'utf-32le' => "\xFF\xFE",
       }
 
       class << self
@@ -90,7 +97,7 @@ module YARD
         # @param [Fixnum] level the logger level to use during parsing. See
         #   {YARD::Logger}
         # @return [void]
-        def parse(paths = ["{lib,app}/**/*.rb", "ext/**/*.c"], excluded = [], level = log.level)
+        def parse(paths = DEFAULT_PATH_GLOB, excluded = [], level = log.level)
           log.debug("Parsing #{paths.inspect} with `#{parser_type}` parser")
           excluded = excluded.map do |path|
             case path
@@ -99,8 +106,8 @@ module YARD
             end
           end
           files = [paths].flatten.
-            map {|p| File.directory?(p) ? "#{p}/**/*.{rb,c}" : p }.
-            map {|p| p.include?("*") ? Dir[p].sort_by {|f| f.length } : p }.flatten.
+            map {|p| File.directory?(p) ? "#{p}/**/*.{rb,c,cc,cxx,cpp}" : p }.
+            map {|p| p.include?("*") ? Dir[p].sort_by {|d| [d.length, d] } : p }.flatten.
             reject {|p| !File.file?(p) || excluded.any? {|re| p =~ re } }
 
           log.enter_level(level) do
@@ -147,16 +154,12 @@ module YARD
         # @return [Hash{Symbol=>Object}] a list of registered parser types
         # @private
         # @since 0.5.6
-        attr_reader :parser_types
-        undef parser_types
         def parser_types; @@parser_types ||= {} end
         def parser_types=(value) @@parser_types = value end
 
         # @return [Hash] a list of registered parser type extensions
         # @private
         # @since 0.5.6
-        attr_reader :parser_type_extensions
-        undef parser_type_extensions
         def parser_type_extensions; @@parser_type_extensions ||= {} end
         def parser_type_extensions=(value) @@parser_type_extensions = value end
 
@@ -166,7 +169,7 @@ module YARD
         # @return [Symbol] the parser type to be used for the extension
         # @since 0.5.6
         def parser_type_for_extension(extension)
-          type = parser_type_extensions.find do |t, exts|
+          type = parser_type_extensions.find do |_t, exts|
             [exts].flatten.any? {|ext| ext === extension }
           end
           validated_parser_type(type ? type.first : :ruby)
@@ -361,8 +364,8 @@ module YARD
         def parse_in_order(*files)
           global_state = OpenStruct.new
 
-          before_parse_list_callbacks.each do |cb|
-            return if cb.call(files, global_state) == false
+          return if before_parse_list_callbacks.any? do |cb|
+            cb.call(files, global_state) == false
           end
 
           OrderedParser.new(global_state, files).parse
@@ -416,11 +419,11 @@ module YARD
         case content
         when String
           @file = File.cleanpath(content)
-          content = convert_encoding(File.read_binary(file))
+          content = convert_encoding(String.new(File.read_binary(file)))
           checksum = Registry.checksum_for(content)
           return if Registry.checksums[file] == checksum
 
-          if Registry.checksums.has_key?(file)
+          if Registry.checksums.key?(file)
             log.info "File '#{file}' was modified, re-processing..."
           end
           Registry.checksums[@file] = checksum
@@ -473,9 +476,8 @@ module YARD
           content.force_encoding('binary')
           ENCODING_BYTE_ORDER_MARKS.each do |encoding, bom|
             bom.force_encoding('binary')
-            if content[0,bom.size] == bom
-              content.force_encoding(encoding)
-              return content
+            if content.start_with?(bom)
+              return content.sub(bom, '').force_encoding(encoding)
             end
           end
           content.force_encoding('utf-8') # UTF-8 is default encoding
@@ -486,10 +488,13 @@ module YARD
       # Runs a {Handlers::Processor} object to post process the parsed statements.
       # @return [void]
       def post_process
-        return unless @parser.respond_to? :enumerator
-        return unless enumerator = @parser.enumerator
-        post = Handlers::Processor.new(self)
-        post.process(enumerator)
+        return unless @parser.respond_to?(:enumerator)
+
+        enumerator = @parser.enumerator
+        if enumerator
+          post = Handlers::Processor.new(self)
+          post.process(enumerator)
+        end
       end
 
       def parser_type=(value)
@@ -509,7 +514,10 @@ module YARD
       # @since 0.5.6
       def parser_class
         klass = self.class.parser_types[parser_type]
-        raise ArgumentError, "invalid parser type '#{parser_type}' or unrecognized file", caller[1..-1] if !klass
+        unless klass
+          raise ArgumentError, "invalid parser type '#{parser_type}' or unrecognized file", caller[1..-1]
+        end
+
         klass
       end
     end
