@@ -62,11 +62,22 @@ RSpec.describe "YARD::Handlers::Ruby::#{LEGACY_PARSER ? "Legacy::" : ""}MixinHan
   it "can mixin a const by complex path" do
     YARD.parse_string <<-eof
       class A1; class B1; class C1; end end end
-      class D1; class E1; class F1; end end end
+      class D1; class E1; module F1; end end end
       A1::B1::C1.include D1::E1::F1
     eof
 
     expect(YARD::Registry.root.instance_mixins).not_to eq [P('D1::E1::F1')]
     expect(P('A1::B1::C1').instance_mixins).to eq [P('D1::E1::F1')]
   end
+
+  it "resolves modules that mix themselves in" do
+    expect(Registry.at('Foo').mixins).to match_array [P('MixMySelfIn'), P('Nested::Foo')]
+  end
+
+  it "ensures the recipient is loaded from another file" do
+    # 002 includes a module into a module defined in 003
+    parse_file [:mixin_handler_002, :mixin_handler_003], __FILE__
+
+    expect(P('A1').instance_mixins).to eq [P('B1')]
+  end
 end
