@@ -21,27 +21,22 @@ RSpec.describe YARD::Templates::Helpers::HtmlHelper do
   end
 
   describe "#charset" do
+    after { Encoding.default_external = 'utf-8' if defined?(Encoding) }
+
     it "returns foo if LANG=foo" do
       expect(ENV).to receive(:[]).with('LANG').and_return('shift_jis') if YARD.ruby18?
-      expect(Encoding.default_external).to receive(:name).and_return('shift_jis') if defined?(Encoding)
+      Encoding.default_external = 'shift_jis' if defined?(Encoding)
       expect(charset).to eq 'shift_jis'
     end
 
-    ['US-ASCII', 'ASCII-7BIT', 'ASCII-8BIT'].each do |type|
+    ['US-ASCII', 'binary', 'ASCII-8BIT'].each do |type|
       it "converts #{type} to iso-8859-1" do
         expect(ENV).to receive(:[]).with('LANG').and_return(type) if YARD.ruby18?
-        expect(Encoding.default_external).to receive(:name).and_return(type) if defined?(Encoding)
+        Encoding.default_external = type if defined?(Encoding)
         expect(charset).to eq 'iso-8859-1'
       end
     end
 
-    it "supports utf8 as an encoding value for utf-8" do
-      type = 'utf8'
-      expect(ENV).to receive(:[]).with('LANG').and_return(type) if YARD.ruby18?
-      expect(Encoding.default_external).to receive(:name).and_return(type) if defined?(Encoding)
-      expect(charset).to eq 'utf-8'
-    end
-
     it "takes file encoding if there is a file" do
       @file = OpenStruct.new(:contents => String.new('foo').force_encoding('sjis'))
       # not the correct charset name, but good enough
@@ -163,7 +158,7 @@ RSpec.describe YARD::Templates::Helpers::HtmlHelper do
 
     it "creates tables (markdown specific)" do
       log.enter_level(Logger::FATAL) do
-        supports_table = %w(RedcarpetCompat Kramdown::Document)
+        supports_table = %w(RedcarpetCompat Kramdown::Document CommonMarker)
         unless supports_table.include?(markup_class(:markdown).to_s)
           pending "This test depends on a markdown engine that supports tables"
         end
@@ -519,6 +514,17 @@ RSpec.describe YARD::Templates::Helpers::HtmlHelper do
         And more.
       eof
     end
+
+    it "warns if you link a constant namespace as if it were a class/module" do
+      @file = CodeObjects::ExtraFileObject.new('myfile.txt', '')
+      YARD.parse_string('CONST = 1')
+
+      logger = double(:log)
+      allow(self).to receive(:log).and_return(logger)
+      expect(logger).to receive(:warn).ordered.with("The namespace of link \"::CONST#meth\" is a constant or invalid.")
+      expect(logger).to receive(:warn).ordered.with("In file `myfile.txt':1: Cannot resolve link to ::CONST#meth from text:\n\t{::CONST#meth}")
+      expect(resolve_links("{::CONST#meth}")).to eq('::CONST#meth')
+    end
   end
 
   describe "#signature" do
